package com.yunzhi.marketing.borker.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.marketing.base.BaseController;
import com.yunzhi.marketing.base.ResponseBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.marketing.borker.service.IBkAccountRecordService;
import com.yunzhi.marketing.borker.entity.BkAccountRecord;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 经纪人佣金流水 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2022-07-26
 */

@Api(tags = "经纪人佣金流水")
@RestController
@RequestMapping("/")
public class BkAccountRecordController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(BkAccountRecordController.class);

    @Autowired
    public IBkAccountRecordService iBkAccountRecordService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/bkAccountRecord",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean bkAccountRecordList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

		    IPage<BkAccountRecord> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<BkAccountRecord> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<BkAccountRecord> result = iBkAccountRecordService.page(pg, queryWrapper);
            return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param bkAccountRecord 实体对象
     * @return
     */
    @RequestMapping(value="/bkAccountRecord",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean bkAccountRecordAdd(@ApiParam("保存内容") @RequestBody BkAccountRecord bkAccountRecord) throws Exception{

        if (iBkAccountRecordService.save(bkAccountRecord)){
            return ResponseBean.success(bkAccountRecord);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/bkAccountRecord/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean bkAccountRecordDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        if(iBkAccountRecordService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param bkAccountRecord 实体对象
     * @return
     */
    @RequestMapping(value="/bkAccountRecord/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean bkAccountRecordUpdate(@ApiParam("对象ID") @PathVariable Integer id,
                                        @ApiParam("更新内容") @RequestBody BkAccountRecord bkAccountRecord) throws Exception{

        if (iBkAccountRecordService.updateById(bkAccountRecord)){
            return ResponseBean.success(iBkAccountRecordService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/bkAccountRecord/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean bkAccountRecordGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        return ResponseBean.success(iBkAccountRecordService.getById(id));
    }
}
