package com.yunzhi.marketing.borker.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.marketing.base.BaseController;
import com.yunzhi.marketing.base.ResponseBean;
import com.yunzhi.marketing.common.CommConstant;
import com.yunzhi.marketing.entity.TaPerson;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.marketing.borker.service.IBkBankCardService;
import com.yunzhi.marketing.borker.entity.BkBankCard;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;

/**
 * <p>
    * 经纪人银行卡信息 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2022-07-26
 */

@Api(tags = "经纪人银行卡信息")
@RestController
@RequestMapping("/api")
public class BkBankCardController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(BkBankCardController.class);

    @Autowired
    public IBkBankCardService iBkBankCardService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/wx/bkBankCard",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean bkBankCardList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                       @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                       HttpServletRequest request) throws Exception {

        String personId = getPersonId(request);

        IPage<BkBankCard> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<BkBankCard> queryWrapper = new QueryWrapper<>();
        queryWrapper.gt("status", CommConstant.STATUS_DELETE);
        queryWrapper.eq("person_id", personId);
        queryWrapper.orderByDesc("create_date");

        IPage<BkBankCard> result = iBkBankCardService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param bkBankCard 实体对象
     * @return
     */
    @RequestMapping(value="/wx/bkBankCard",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean bkBankCardAdd(@ApiParam("保存内容") @RequestBody BkBankCard bkBankCard,
                                      HttpServletRequest request) throws Exception {
        String personId = getPersonId(request);
        bkBankCard.setPersonId(personId);

        if (iBkBankCardService.save(bkBankCard)){
            return ResponseBean.success(bkBankCard);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/wx/bkBankCard/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean bkBankCardDelete(@ApiParam("对象ID") @PathVariable Integer id,
                                         HttpServletRequest request) throws Exception {
        String personId = getPersonId(request);
        BkBankCard bkBankCard = iBkBankCardService.getById(id);
        if (null != bkBankCard && !personId.equals(bkBankCard.getPersonId())) {
            return ResponseBean.error("操作异常", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        if(iBkBankCardService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param bkBankCard 实体对象
     * @return
     */
    @RequestMapping(value="/wx/bkBankCard/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean bkBankCardUpdate(@ApiParam("对象ID") @PathVariable Integer id,
                                         @ApiParam("更新内容") @RequestBody BkBankCard bkBankCard,
                                         HttpServletRequest request) throws Exception {
        String personId = getPersonId(request);
        BkBankCard origin = iBkBankCardService.getById(id);
        if (null == origin || CommConstant.STATUS_DELETE.equals(origin.getStatus()) || !personId.equals(origin.getPersonId())) {
            return ResponseBean.error("未找到数据", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        bkBankCard.setPersonId(personId);

        if (iBkBankCardService.updateById(bkBankCard)){
            return ResponseBean.success(iBkBankCardService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/wx/bkBankCard/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean bkBankCardGet(@ApiParam("对象ID") @PathVariable Integer id,
                                      HttpServletRequest request) throws Exception{
        String personId = getPersonId(request);
        BkBankCard origin = iBkBankCardService.getById(id);
        if (null == origin || CommConstant.STATUS_DELETE.equals(origin.getStatus()) || !personId.equals(origin.getPersonId())) {
            return ResponseBean.error("未找到数据", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }
        return ResponseBean.success(origin);
    }
}
